@@ -90,6 +90,7 @@ SF2 <- cbind(numdead2, numalive2=20 - numdead2)
 cat("a1: single response glm model but with a binomial pair of y columns, with ldose1 data degree=2\n\n")
 a1 <-  earth(SF ~ sex + ldose + ldose1, glm=list(family="binomial"), trace=4, pmethod="none", degree=2)
 print.earth.models(a1)
+printh(evimp(a1, trim=FALSE, sqrt=FALSE))
 printh(evimp(a1, trim=FALSE, sqrt=TRUE)) # this tests sqrt param with negative evimps
 a1update <- update(a1, trace=0)
 check.models.equal(a1, a1update, msg="a1update a1")
@@ -1320,8 +1321,7 @@ cat("a.intercept.only: intercept only logistic model\n\n")
 # cv fold and intercept-only in 2nd cv fold, that way we test both.
 set.seed(3)
 df <- data.frame(aaa = round(runif(18)), bbb = runif(18), ccc = rnorm(18))
-a <- earth(survived ~ ., data=etitanic, glm=list(family=binomial), nfold=2)
-a.intercept.only <- earth(aaa ~ bbb + ccc, data = df, glm=list(family=binomial), trace=1)
+a.intercept.only <- earth(aaa ~ bbb + ccc, data = df, glm=list(family=binomial), trace=1, nfold=2)
 print.earth.models(a.intercept.only)
 cat("\nsummary(a.intercept.only, details=TRUE)\n\n", sep="")
 print(summary(a.intercept.only, details=TRUE))
@@ -1342,6 +1342,8 @@ printh(predict(a.intercept.only, newdata=new.df, type="class"))
 # cat("Expect Warning: predict.earth: returning the earth (not glm) terms\n")
 printh(predict(a.intercept.only, newdata=new.df, type="terms"))
 
+set.seed(1235)
+a <- earth(survived ~ ., data=etitanic, glm=list(family=binomial), nfold=2)
 plot.earth.models(list(a.intercept.only, a), main="plot.earth.models\nlist(a.intercept.only, a)")
 plot.earth.models(list(a, a.intercept.only), main="plot.earth.models\nlist(a, a.intercept.only)", legend.pos="topleft", jitter=.01)
 # nothing will plot for the next call
